@@ -2,7 +2,7 @@ from json import loads
 from os import path
 from sys import argv
 
-print(os.path.dirname(os.path.realpath(sys.argv[0])))
+print(path.dirname(path.realpath(argv[0])))
 
 def nori(args):
     verb = None
